import * as z from "zod/v4";

export const imageUploadSchema = z.object({
  imageName: z.string().min(1, "Image name is required"),
  file: z
    .custom<FileList>()
    .refine((files) => files instanceof FileList && files.length > 0, {
      message: "Image file is required",
    }),
})

export const imageSchema = z.object({
  imageName: z.string().min(1, "Image name is required"),
  fileKey: z.string().min(1, "File key is required"),
  originalFile: z.string().min(1, "Original file is required"),
  uploadDate: z.date(),
  altText: z.string().optional(),
  description: z.string().optional(),
  imageData:  z.string().optional(),
  creationMonth: z.coerce.number().int().min(1).max(12).optional(),
  creationYear: z.coerce.number().int().min(1900).max(2100).optional(),
  creationDate: z.date().optional(),
})